Saraki (wip)
============

A framework for multi-tenant applications

This framework aims to help you build as quick as possible multi-tenant
applications.

This is a work in progress, so things could change and break, but you can try
it if you want.


.. image:: https://img.shields.io/pypi/v/saraki.svg
        :target: https://pypi.python.org/pypi/saraki

.. image:: https://img.shields.io/travis/mbarakaja/saraki.svg
        :target: https://travis-ci.org/mbarakaja/saraki

.. image:: https://readthedocs.org/projects/saraki/badge/?version=latest
        :target: https://saraki.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Work in progress
~~~~~~~~~~~~~~~~

* User management
* Organization management
* Membership management
* Authentication and Authorization system
